
// Label Chooser for Magic Launch
// Copyright 2010 Michel Fortin
//
// This file is published under the terms of the Boost Software License 1.0.
//
// Boost Software License - Version 1.0 - August 17th, 2003
//
// Permission is hereby granted, free of charge, to any person or organization
// obtaining a copy of the software and accompanying documentation covered by
// this license (the "Software") to use, reproduce, display, distribute,
// execute, and transmit the Software, and to prepare derivative works of the
// Software, and to permit third-parties to whom the Software is furnished to
// do so, all subject to the following:
//
// The copyright notices in the Software and this entire statement, including
// the above license grant, this restriction and the following disclaimer,
// must be included in all copies of the Software, in whole or in part, and
// all derivative works of the Software, unless such copies or derivative
// works are solely in the form of machine-executable object code generated by
// a source language processor.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
// SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
// FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.

#import <Cocoa/Cocoa.h>


/*!
 @abstract   Control to choose a file label, as seen in the Finder.
 @discussion A label chooser control displays a horizontal list of
 buttons for choosing a color label for a file. It looks and works 
 similarily to the label chooser found in the Finder.
 
 The label chooser manages an int value that represents the label index.
 This value is the same as the one used by the file system to keep track
 of file labels. Buttons displayed in this control are not necessarily 
 in the same order as the label index, instead they mimick the label order 
 used by the Finder.
 
 The label chooser control can optionally be linked to a text field
 used to display the name of the label under the mouse pointer. Either 
 connect the labelText outlet from Interface builder or set the 
 labelText property.
 
 Note: If you set labelText, the label chooser will expects localized 
 quotation marks from the default localized strings of the application. 
 Thus, you should create an entry for a localized string "“%@”" in your 
 bundle's Localizable.strings file.
 */
@interface MLLabelChooser : NSControl {
	NSArray *labelButtons;
	IBOutlet NSTextField *labelText;
	int label;
}

/*!
 @abstract   Text field used to display the name of the label currently 
 under the mouse pointer.
 @discussion If not nil, labelText's value will be updated when the mouse 
 pointer enters or leaves a label button in the chooser.
 */
@property (retain) NSTextField *labelText;


@end

